@@ -55,8 +55,9 @@ static void copy_with_escape(
 	size_t i;
 	size_t plen;
 
-	if (p == NULL)
+	if (!p) {
 		return;
+	}
 	plen = strlen(p);
 	for (i = (size_t)0; i < plen; ++i) {
 		switch (p[i]) {
@@ -96,7 +97,7 @@ static void ixmlPrintDomTreeRecursive(
 	const char *nodeValue = NULL;
 	IXML_Node *child = NULL, *sibling = NULL;
 
-	if (nodeptr != NULL) {
+	if (nodeptr) {
 		nodeName = (const char *)ixmlNode_getNodeName(nodeptr);
 		nodeValue = ixmlNode_getNodeValue(nodeptr);
 
@@ -129,7 +130,7 @@ static void ixmlPrintDomTreeRecursive(
 			ixml_membuf_append_str(buf, "=\"");
 			copy_with_escape(buf, nodeValue);
 			ixml_membuf_append_str(buf, "\"");
-			if (nodeptr->nextSibling != NULL) {
+			if (nodeptr->nextSibling) {
 				ixml_membuf_append_str(buf, " ");
 				ixmlPrintDomTreeRecursive(
 					nodeptr->nextSibling, buf);
@@ -139,13 +140,13 @@ static void ixmlPrintDomTreeRecursive(
 		case eELEMENT_NODE:
 			ixml_membuf_append_str(buf, "<");
 			ixml_membuf_append_str(buf, nodeName);
-			if (nodeptr->firstAttr != NULL) {
+			if (nodeptr->firstAttr) {
 				ixml_membuf_append_str(buf, " ");
 				ixmlPrintDomTreeRecursive(
 					nodeptr->firstAttr, buf);
 			}
 			child = ixmlNode_getFirstChild(nodeptr);
-			if (child != NULL &&
+			if (child &&
 				ixmlNode_getNodeType(child) == eELEMENT_NODE) {
 				ixml_membuf_append_str(buf, ">\r\n");
 			} else {
@@ -160,7 +161,7 @@ static void ixmlPrintDomTreeRecursive(
 			ixml_membuf_append_str(buf, nodeName);
 
 			sibling = ixmlNode_getNextSibling(nodeptr);
-			if (sibling != NULL &&
+			if (sibling &&
 				ixmlNode_getNodeType(sibling) == eTEXT_NODE) {
 				ixml_membuf_append_str(buf, ">");
 			} else {
@@ -197,7 +198,7 @@ static void ixmlPrintDomTree(
 	const char *nodeValue = NULL;
 	IXML_Node *child = NULL;
 
-	if (nodeptr == NULL || buf == NULL) {
+	if (!nodeptr || !buf) {
 		return;
 	}
 
@@ -221,13 +222,12 @@ static void ixmlPrintDomTree(
 	case eELEMENT_NODE:
 		ixml_membuf_append_str(buf, "<");
 		ixml_membuf_append_str(buf, nodeName);
-		if (nodeptr->firstAttr != NULL) {
+		if (nodeptr->firstAttr) {
 			ixml_membuf_append_str(buf, " ");
 			ixmlPrintDomTreeRecursive(nodeptr->firstAttr, buf);
 		}
 		child = ixmlNode_getFirstChild(nodeptr);
-		if (child != NULL &&
-			ixmlNode_getNodeType(child) == eELEMENT_NODE) {
+		if (child && ixmlNode_getNodeType(child) == eELEMENT_NODE) {
 			ixml_membuf_append_str(buf, ">\r\n");
 		} else {
 			ixml_membuf_append_str(buf, ">");
@@ -268,7 +268,7 @@ static void ixmlDomTreetoString(
 	const char *nodeValue = NULL;
 	IXML_Node *child = NULL;
 
-	if (nodeptr == NULL || buf == NULL) {
+	if (!nodeptr || !buf) {
 		return;
 	}
 
@@ -293,13 +293,12 @@ static void ixmlDomTreetoString(
 	case eELEMENT_NODE:
 		ixml_membuf_append_str(buf, "<");
 		ixml_membuf_append_str(buf, nodeName);
-		if (nodeptr->firstAttr != NULL) {
+		if (nodeptr->firstAttr) {
 			ixml_membuf_append_str(buf, " ");
 			ixmlPrintDomTreeRecursive(nodeptr->firstAttr, buf);
 		}
 		child = ixmlNode_getFirstChild(nodeptr);
-		if (child != NULL &&
-			ixmlNode_getNodeType(child) == eELEMENT_NODE) {
+		if (child && ixmlNode_getNodeType(child) == eELEMENT_NODE) {
 			ixml_membuf_append_str(buf, ">");
 		} else {
 			ixml_membuf_append_str(buf, ">");
@@ -326,7 +325,7 @@ static void ixmlDomTreetoString(
 
 int ixmlLoadDocumentEx(const char *xmlFile, IXML_Document **doc)
 {
-	if (xmlFile == NULL || doc == NULL) {
+	if (!xmlFile || !doc) {
 		return IXML_INVALID_PARAMETER;
 	}
 
@@ -348,7 +347,7 @@ DOMString ixmlPrintDocument(IXML_Document *doc)
 	ixml_membuf memBuf;
 	ixml_membuf *buf = &memBuf;
 
-	if (rootNode == NULL) {
+	if (!rootNode) {
 		return NULL;
 	}
 
@@ -364,7 +363,7 @@ DOMString ixmlPrintNode(IXML_Node *node)
 	ixml_membuf memBuf;
 	ixml_membuf *buf = &memBuf;
 
-	if (node == NULL) {
+	if (!node) {
 		return NULL;
 	}
 
@@ -380,7 +379,7 @@ DOMString ixmlDocumenttoString(IXML_Document *doc)
 	ixml_membuf memBuf;
 	ixml_membuf *buf = &memBuf;
 
-	if (rootNode == NULL) {
+	if (!rootNode) {
 		return NULL;
 	}
 
@@ -396,7 +395,7 @@ DOMString ixmlNodetoString(IXML_Node *node)
 	ixml_membuf memBuf;
 	ixml_membuf *buf = &memBuf;
 
-	if (node == NULL) {
+	if (!node) {
 		return NULL;
 	}
 
@@ -417,10 +416,9 @@ void ixmlSetBeforeFree(IXML_BeforeFreeNode_t hndlr)
 
 int ixmlParseBufferEx(const char *buffer, IXML_Document **retDoc)
 {
-	if (buffer == NULL || retDoc == NULL) {
+	if (!buffer || !retDoc) {
 		return IXML_INVALID_PARAMETER;
 	}
-
 	if (buffer[0] == '\0') {
 		return IXML_INVALID_PARAMETER;
 	}
@@ -439,7 +437,7 @@ IXML_Document *ixmlParseBuffer(const char *buffer)
 
 DOMString ixmlCloneDOMString(const DOMString src)
 {
-	if (src == NULL) {
+	if (!src) {
 		return NULL;
 	}
 
@@ -448,7 +446,7 @@ DOMString ixmlCloneDOMString(const DOMString src)
 
 void ixmlFreeDOMString(DOMString buf)
 {
-	if (buf != NULL) {
+	if (buf) {
 		free(buf);
 	}
 }
