@@ -40,12 +40,11 @@
 	#define _GNU_SOURCE /* For strcasestr() in string.h */
 #endif
 
-#include "config.h"
+#include "config.h" /* IWYU pragma: keep */
 
 #include "httpparser.h"
 #include "statcodes.h"
 #include "strintmap.h"
-#include "unixutil.h"
 #include "upnpdebug.h"
 
 #include <assert.h>
@@ -122,7 +121,7 @@ str_int_entry Http_Header_Names[NUM_HTTP_HEADER_NAMES] = {
  *	OUT scanner_t* scanner ; Scanner Object to be initialized
  *	IN membuffer* bufptr ;	 Buffer to be copied
  *
- * Description :	Intialize scanner
+ * Description : Initialize scanner
  *
  * Return : void ;
  *
@@ -208,7 +207,7 @@ static UPNP_INLINE int is_qdtext_char(int c)
  *
  * Return : parse_status_t ;
  *	PARSE_OK
- *	PARSE_INCOMPLETE		-- not enuf chars to get a token
+ *	PARSE_INCOMPLETE		-- not enough chars to get a token
  *	PARSE_FAILURE			-- bad msg format
  *
  * Note :
@@ -258,7 +257,7 @@ static parse_status_t scanner_get_token(
 		/* scan CRLF */
 		token->buf = cursor++;
 		if (cursor == null_terminator)
-			/* not enuf info to determine CRLF */
+			/* not enough info to determine CRLF */
 			return PARSE_INCOMPLETE;
 		if (*cursor != TOKCHAR_LF) {
 			/* couldn't match CRLF; match as CR */
@@ -425,7 +424,7 @@ void httpmsg_destroy(http_message_t *msg)
 		ListDestroy(&msg->headers, 1);
 		membuffer_destroy(&msg->msg);
 		membuffer_destroy(&msg->status_msg);
-		free(msg->urlbuf);
+		free(msg->url_buf);
 		msg->initialized = 0;
 	}
 }
@@ -512,7 +511,7 @@ http_header_t *httpmsg_find_hdr(
  *
  * Return : parse_status_t ;
  *	PARSE_OK
- *	PARSE_INCOMPLETE		-- not enuf chars to get a token
+ *	PARSE_INCOMPLETE		-- not enough chars to get a token
  *	PARSE_FAILURE			-- bad msg format
  ************************************************************************/
 static UPNP_INLINE parse_status_t skip_blank_lines(scanner_t *scanner)
@@ -890,7 +889,7 @@ static UPNP_INLINE parse_status_t match_char(
  *
  * args for ...
  *   %d,    int *     (31-bit positive integer)
- *   %x,    int *     (31-bit postive number encoded as hex)
+ *   %x,    int *     (31-bit positive number encoded as hex)
  *   %s,    memptr*  (simple identifier)
  *   %q,    memptr*  (quoted string)
  *   %S,    memptr*  (non-whitespace string)
@@ -1230,10 +1229,10 @@ static UPNP_INLINE void parser_init(http_parser_t *parser)
  *	PARSE_INCOMPLETE
  *	PARSE_NO_MATCH
  ************************************************************************/
-static parse_status_t parser_parse_requestline(http_parser_t *parser)
+static parse_status_t parser_parse_request_line(http_parser_t *parser)
 {
 	parse_status_t status;
-	http_message_t *hmsg = &parser->msg;
+	http_message_t *h_msg = &parser->msg;
 	memptr method_str;
 	memptr version_str;
 	int index;
@@ -1270,7 +1269,7 @@ static parse_status_t parser_parse_requestline(http_parser_t *parser)
 			return PARSE_FAILURE;
 		}
 
-		hmsg->method = HTTPMETHOD_SIMPLEGET;
+		h_msg->method = HTTPMETHOD_SIMPLEGET;
 
 		/* remove excessive leading slashes, keep one slash */
 		while (url_str.length >= 2 && url_str.buf[0] == '/' &&
@@ -1279,13 +1278,13 @@ static parse_status_t parser_parse_requestline(http_parser_t *parser)
 			url_str.length--;
 		}
 		/* store url */
-		hmsg->urlbuf = str_alloc(url_str.buf, url_str.length);
-		if (hmsg->urlbuf == NULL) {
+		h_msg->url_buf = str_alloc(url_str.buf, url_str.length);
+		if (h_msg->url_buf == NULL) {
 			/* out of mem */
 			parser->http_error_code = HTTP_INTERNAL_SERVER_ERROR;
 			return PARSE_FAILURE;
 		}
-		if (parse_uri(hmsg->urlbuf, url_str.length, &hmsg->uri) !=
+		if (parse_uri(h_msg->url_buf, url_str.length, &h_msg->uri) !=
 			HTTP_SUCCESS) {
 			return PARSE_FAILURE;
 		}
@@ -1310,13 +1309,13 @@ static parse_status_t parser_parse_requestline(http_parser_t *parser)
 		url_str.length--;
 	}
 	/* store url */
-	hmsg->urlbuf = str_alloc(url_str.buf, url_str.length);
-	if (hmsg->urlbuf == NULL) {
+	h_msg->url_buf = str_alloc(url_str.buf, url_str.length);
+	if (h_msg->url_buf == NULL) {
 		/* out of mem */
 		parser->http_error_code = HTTP_INTERNAL_SERVER_ERROR;
 		return PARSE_FAILURE;
 	}
-	if (parse_uri(hmsg->urlbuf, url_str.length, &hmsg->uri) !=
+	if (parse_uri(h_msg->url_buf, url_str.length, &h_msg->uri) !=
 		HTTP_SUCCESS) {
 		return PARSE_FAILURE;
 	}
@@ -1341,21 +1340,21 @@ static parse_status_t parser_parse_requestline(http_parser_t *parser)
 	num_scanned = sscanf(version_str.buf,
 #endif
 		"%d . %d",
-		&hmsg->major_version,
-		&hmsg->minor_version);
+		&h_msg->major_version,
+		&h_msg->minor_version);
 	version_str.buf[version_str.length] = save_char; /* restore */
 	if (num_scanned != 2 ||
 		/* HTTP version equals to 1.0 should fail for MSEARCH as
 		 * required by the UPnP certification tool */
-		hmsg->major_version < 0 ||
-		(hmsg->major_version == 1 && hmsg->minor_version < 1 &&
+		h_msg->major_version < 0 ||
+		(h_msg->major_version == 1 && h_msg->minor_version < 1 &&
 			Http_Method_Table[index].id == HTTPMETHOD_MSEARCH)) {
 		parser->http_error_code = HTTP_HTTP_VERSION_NOT_SUPPORTED;
 		/* error; bad http version */
 		return PARSE_FAILURE;
 	}
 
-	hmsg->method = (http_method_t)Http_Method_Table[index].id;
+	h_msg->method = (http_method_t)Http_Method_Table[index].id;
 	parser->position = POS_HEADERS; /* move to headers */
 
 	return PARSE_OK;
@@ -1378,7 +1377,7 @@ static parse_status_t parser_parse_requestline(http_parser_t *parser)
 parse_status_t parser_parse_responseline(http_parser_t *parser)
 {
 	parse_status_t status;
-	http_message_t *hmsg = &parser->msg;
+	http_message_t *h_msg = &parser->msg;
 	memptr line;
 	char save_char;
 	int num_scanned;
@@ -1393,8 +1392,8 @@ parse_status_t parser_parse_responseline(http_parser_t *parser)
 		return status;
 	/* response line */
 	/*status = match( &parser->scanner, "%ihttp%w/%w%d\t.\t%d\t%d\t%L%c", */
-	/*  &hmsg->major_version, &hmsg->minor_version, */
-	/*  &hmsg->status_code, &hmsg->status_msg ); */
+	/*  &h_msg->major_version, &h_msg->minor_version, */
+	/*  &h_msg->status_code, &h_msg->status_msg ); */
 	status = match(&parser->scanner, "%ihttp%w/%w%L%c", &line);
 	if (status != (parse_status_t)PARSE_OK)
 		return status;
@@ -1407,12 +1406,12 @@ parse_status_t parser_parse_responseline(http_parser_t *parser)
 	num_scanned = sscanf(line.buf,
 #endif
 		"%d . %d %d",
-		&hmsg->major_version,
-		&hmsg->minor_version,
-		&hmsg->status_code);
+		&h_msg->major_version,
+		&h_msg->minor_version,
+		&h_msg->status_code);
 	line.buf[line.length] = save_char; /* restore */
-	if (num_scanned != 3 || hmsg->major_version < 0 ||
-		hmsg->minor_version < 0 || hmsg->status_code < 0)
+	if (num_scanned != 3 || h_msg->major_version < 0 ||
+		h_msg->minor_version < 0 || h_msg->status_code < 0)
 		/* bad response line */
 		return PARSE_FAILURE;
 	/* point to status msg */
@@ -1434,7 +1433,7 @@ parse_status_t parser_parse_responseline(http_parser_t *parser)
 		p++;
 	/* now, p is at start of status msg */
 	n = line.length - ((size_t)p - (size_t)line.buf);
-	if (membuffer_assign(&hmsg->status_msg, p, n) != 0) {
+	if (membuffer_assign(&h_msg->status_msg, p, n) != 0) {
 		/* out of mem */
 		parser->http_error_code = HTTP_INTERNAL_SERVER_ERROR;
 		return PARSE_FAILURE;
@@ -1587,7 +1586,7 @@ parse_status_t parser_parse_headers(http_parser_t *parser)
 				hdr_value.length);
 			if (ret == UPNP_E_OUTOF_MEMORY ||
 				ret2 == UPNP_E_OUTOF_MEMORY) {
-				/* not enuf mem */
+				/* not enough memory */
 				parser->http_error_code =
 					HTTP_INTERNAL_SERVER_ERROR;
 				return PARSE_FAILURE;
@@ -1839,7 +1838,7 @@ static UPNP_INLINE parse_status_t parser_parse_entity_until_close(
  ************************************************************************/
 parse_status_t parser_get_entity_read_method(http_parser_t *parser)
 {
-	http_message_t *hmsg = &parser->msg;
+	http_message_t *h_msg = &parser->msg;
 	int response_code;
 	memptr hdr_value;
 
@@ -1856,8 +1855,8 @@ parse_status_t parser_get_entity_read_method(http_parser_t *parser)
 
 	/* * no body for 1xx, 204, 304 and HEAD, GET, */
 	/*      SUBSCRIBE, UNSUBSCRIBE */
-	if (hmsg->is_request) {
-		switch (hmsg->method) {
+	if (h_msg->is_request) {
+		switch (h_msg->method) {
 		case HTTPMETHOD_HEAD:
 		case HTTPMETHOD_GET:
 			/*case HTTPMETHOD_POST: */
@@ -1873,19 +1872,19 @@ parse_status_t parser_get_entity_read_method(http_parser_t *parser)
 		}
 	} else /* response */
 	{
-		response_code = hmsg->status_code;
+		response_code = h_msg->status_code;
 
 		if (response_code == 204 || response_code == 304 ||
 			(response_code >= 100 && response_code <= 199) ||
-			hmsg->request_method ==
+			h_msg->request_method ==
 				(http_method_t)HTTPMETHOD_HEAD ||
-			hmsg->request_method ==
+			h_msg->request_method ==
 				(http_method_t)HTTPMETHOD_MSEARCH ||
-			hmsg->request_method ==
+			h_msg->request_method ==
 				(http_method_t)HTTPMETHOD_SUBSCRIBE ||
-			hmsg->request_method ==
+			h_msg->request_method ==
 				(http_method_t)HTTPMETHOD_UNSUBSCRIBE ||
-			hmsg->request_method ==
+			h_msg->request_method ==
 				(http_method_t)HTTPMETHOD_NOTIFY) {
 			parser->position = POS_COMPLETE;
 			return PARSE_SUCCESS;
@@ -1893,7 +1892,7 @@ parse_status_t parser_get_entity_read_method(http_parser_t *parser)
 	}
 
 	/* * transfer-encoding -- used to indicate chunked data */
-	if (httpmsg_find_hdr(hmsg, HDR_TRANSFER_ENCODING, &hdr_value)) {
+	if (httpmsg_find_hdr(h_msg, HDR_TRANSFER_ENCODING, &hdr_value)) {
 		if (raw_find_str(&hdr_value, "chunked") >= 0) {
 			/* read method to use chunked transfer encoding */
 			parser->ent_position = ENTREAD_USING_CHUNKED;
@@ -1907,7 +1906,7 @@ parse_status_t parser_get_entity_read_method(http_parser_t *parser)
 		}
 	}
 	/* * use content length */
-	if (httpmsg_find_hdr(hmsg, HDR_CONTENT_LENGTH, &hdr_value)) {
+	if (httpmsg_find_hdr(h_msg, HDR_CONTENT_LENGTH, &hdr_value)) {
 		parser->content_length =
 			(unsigned int)raw_to_int(&hdr_value, 10);
 		parser->ent_position = ENTREAD_USING_CLEN;
@@ -1916,10 +1915,10 @@ parse_status_t parser_get_entity_read_method(http_parser_t *parser)
 	/* * multi-part/byteranges not supported (yet) */
 
 	/* * read until connection is closed */
-	if (hmsg->is_request) {
+	if (h_msg->is_request) {
 		/* set hack flag for NOTIFY methods; if set to 1 this is */
 		/*  a valid SSDP notify msg */
-		if (hmsg->method == (http_method_t)HTTPMETHOD_NOTIFY) {
+		if (h_msg->method == (http_method_t)HTTPMETHOD_NOTIFY) {
 			parser->valid_ssdp_notify_hack = 1;
 		}
 
@@ -2064,7 +2063,7 @@ parse_status_t parser_parse(http_parser_t *parser)
 			break;
 
 		case POS_REQUEST_LINE:
-			status = parser_parse_requestline(parser);
+			status = parser_parse_request_line(parser);
 
 			break;
 
@@ -2155,7 +2154,7 @@ int raw_to_int(memptr *raw_value, int base)
  * Function: raw_find_str
  *
  * Parameters:
- *	IN memptr* raw_value ; Buffer containg the string
+ *	IN memptr* raw_value ; Buffer containing the string
  *	IN const char* str ;	Substring to be found
  *
  * Description: Find a substring from raw character string buffer
@@ -2212,7 +2211,8 @@ const char *method_to_str(http_method_t method)
 {
 	int index;
 
-	index = map_int_to_str(method, Http_Method_Table, NUM_HTTP_METHODS);
+	index = map_int_to_str(
+		(int)method, Http_Method_Table, NUM_HTTP_METHODS);
 
 	assert(index != -1);
 
@@ -2220,24 +2220,24 @@ const char *method_to_str(http_method_t method)
 }
 
 #ifdef DEBUG
-void print_http_headers(http_message_t *hmsg)
+void print_http_headers(http_message_t *h_msg)
 {
 	ListNode *node;
 	/* NNS:	 dlist_node *node; */
 	http_header_t *header;
 
 	/* print start line */
-	if (hmsg->is_request) {
+	if (h_msg->is_request) {
 		UpnpPrintf(UPNP_ALL,
 			HTTP,
 			__FILE__,
 			__LINE__,
 			"method = %d, version = %d.%d, url = %.*s\n",
-			hmsg->method,
-			hmsg->major_version,
-			hmsg->minor_version,
-			(int)hmsg->uri.pathquery.size,
-			hmsg->uri.pathquery.buff);
+			h_msg->method,
+			h_msg->major_version,
+			h_msg->minor_version,
+			(int)h_msg->uri.pathquery.size,
+			h_msg->uri.pathquery.buff);
 	} else {
 		UpnpPrintf(UPNP_ALL,
 			HTTP,
@@ -2245,16 +2245,16 @@ void print_http_headers(http_message_t *hmsg)
 			__LINE__,
 			"resp status = %d, version = %d.%d, status msg = "
 			"%.*s\n",
-			hmsg->status_code,
-			hmsg->major_version,
-			hmsg->minor_version,
-			(int)hmsg->status_msg.length,
-			hmsg->status_msg.buf);
+			h_msg->status_code,
+			h_msg->major_version,
+			h_msg->minor_version,
+			(int)h_msg->status_msg.length,
+			h_msg->status_msg.buf);
 	}
 
 	/* print headers */
-	node = ListHead(&hmsg->headers);
-	/* NNS: node = dlist_first_node( &hmsg->headers ); */
+	node = ListHead(&h_msg->headers);
+	/* NNS: node = dlist_first_node( &h_msg->headers ); */
 	while (node != NULL) {
 		header = (http_header_t *)node->item;
 		/* NNS: header = (http_header_t *)node->data; */
@@ -2268,8 +2268,8 @@ void print_http_headers(http_message_t *hmsg)
 			(int)header->value.length,
 			header->value.buf);
 
-		node = ListNext(&hmsg->headers, node);
-		/* NNS: node = dlist_next( &hmsg->headers, node ); */
+		node = ListNext(&h_msg->headers, node);
+		/* NNS: node = dlist_next( &h_msg->headers, node ); */
 	}
 }
 #endif /* DEBUG */
