@@ -64,7 +64,7 @@
 	#include <fcntl.h>
 	#include <sys/stat.h>
 
-	#include "posix_overwrites.h"
+	#include "posix_overwrites.h" // IWYU pragma: keep
 
 /*!
  * Response Types.
@@ -135,18 +135,17 @@ static const char *gMediaTypes[] = {
 	#define NUM_HTTP_HEADER_NAMES 33
 
 	#define ASCTIME_R_BUFFER_SIZE 26
-	#ifdef _WIN32
+
 static char *web_server_asctime_r(const struct tm *tm, char *buf)
 {
-	if (tm == NULL || buf == NULL)
+	if (!tm || !buf)
+		return NULL;
+
+	if (!strftime(buf, ASCTIME_R_BUFFER_SIZE, "%a %b %d %H:%M:%S %Y\n", tm))
 		return NULL;
 
-	asctime_s(buf, ASCTIME_R_BUFFER_SIZE, tm);
 	return buf;
 }
-	#else
-		#define web_server_asctime_r asctime_r
-	#endif
 
 /* sorted by file extension; must have 'NUM_MEDIA_TYPES' extensions */
 static const char *gEncodedMediaTypes =
@@ -714,7 +713,7 @@ static void ToUpperCase(
 /*!
  * \brief Finds a substring from a string in a case insensitive way.
  *
- * \return A pointer to the first occurence of s2 in s1.
+ * \return A pointer to the first occurrence of s2 in s1.
  */
 static char *StrStr(
 	/*! Input string. */
@@ -1175,7 +1174,7 @@ static int process_request(
 	SOCKINFO *info,
 	/*! [in] HTTP Request message. */
 	http_message_t *req,
-	/*! [out] Tpye of response. */
+	/*! [out] Type of response. */
 	enum resp_type *rtype,
 	/*! [out] Headers. */
 	membuffer *headers,
