@@ -1,4 +1,3 @@
-
 /*!
  * \file
  *
@@ -7,12 +6,11 @@
  * \author Marcelo Roberto Jimenez
  */
 
-#include "config.h"
-
-#include "SSDPResultData.h"
 #include "SSDPResultDataCallback.h"
 
-void SSDPResultData_Callback(const SSDPResultData *p)
+#include "SSDPResultData.h"
+
+void SSDPResultData_Callback(SSDPResultData *p)
 {
 	Upnp_FunPtr callback = SSDPResultData_get_CtrlptCallback(p);
 	callback(UPNP_DISCOVERY_SEARCH_RESULT,
